@@ -1,10 +1,13 @@
 bc.data.frame <-
 function(x, stack100,
-         col_fill, col_color, col.trans, fill_spit, theme,
+         col_fill, col_color, col.trans,
+         fill_split, fill_scaled, fill_chroma, theme,
          horiz, gap, prop, scale_y, 
          xlab, ylab, main,
          value_labels, label.size, beside,
-         rotate_x, offset, break_x, sort_x,
+         rotate_x, offset,
+         axis_fmt, axis_x_pre, axis_y_pre,
+         break_x, sort_x,
          labels, labels_color, labels_cex, labels_digits,
          labels_position, labels_cut,
          xlab_adj, ylab_adj, bm.adj, lm.adj, tm.adj, rm.adj,
@@ -64,11 +67,14 @@ function(x, stack100,
         }
 
         .bc.main(x[,i], y=NULL, by=NULL, stack100,
-          col_fill, col_color, col.trans, fill_spit, theme,
+          col_fill, col_color, col.trans, fill_split,
+          fill_scaled, fill_chroma, theme,
           horiz, gap, prop, scale_y, 
           xlab, ylab, main,
           value_labels=NULL, label.size, beside,
-          rotate_x, offset, break_x, sort_x,
+          rotate_x, offset,
+          axis_fmt, axis_x_pre, axis_y_pre,
+          break_x, sort_x,
           labels, labels_color, labels_cex, labels_digits,
           labels_position, labels_cut,
           xlab_adj, ylab_adj, bm.adj, lm.adj, tm.adj, rm.adj,
