@@ -1,8 +1,10 @@
 .plt.fit <- 
-function(x.lv, y.lv, fit.line, fit_power) {
+function(x.lv, y.lv, fit.line, fit_power, fit_new) {
 
 # Need to implement  xlog  and xylog
 
+  digits_d <- getOption("digits_d")
+
   b00 <- NULL
   b11 <- NULL
   Rsqq <- NULL
@@ -15,18 +17,27 @@ function(x.lv, y.lv, fit.line, fit_power) {
     y.lv <- y.lv[od]
 
     # fit line
+    # ---------------------------------------
+    y.new <- NULL  # new values of y computed from fit_new
+    if (!is.null(fit_new)) n.new <- length(fit_new)
+
+    # l.ln: loess or linear fit, including of transformed data
     if (fit.line == "loess")
       l.ln <- loess(y.lv ~ x.lv)
     else if (fit.line == "lm")
       l.ln <- lm(y.lv ~ x.lv)
     else if (fit.line == "null")
       l.ln <- lm(y.lv ~ 1)
+
+    # f.ln: fitted values, either directly or from back transformation
     if (fit.line %in% c("loess", "lm", "null"))
       f.ln <- fitted(l.ln)
     if (fit.line %in% c("lm", "null")) {
       b00 <- l.ln$coefficients[1] 
       b11 <- l.ln$coefficients[2] 
       Rsqq <- summary(l.ln)$r.squared
+      if (!is.null(fit_new)) 
+        y.new <- round(b00 + (b11*fit_new), digits_d)  # linear reg
     }
 
     if (fit.line %in% c("quad", "power")) {  # quad model
@@ -39,7 +50,8 @@ function(x.lv, y.lv, fit.line, fit_power) {
       b00 <- l.ln$coefficients[1]
       b11 <- l.ln$coefficients[2]
       f.ln <- (b00 + (b11*x.lv))^fit_power
-      Rsqq <- summary(l.ln)$r.squared
+      if (!is.null(fit_new)) 
+        y.new <- round((b00 + (b11*fit_new))^fit_power, digits_d)
     }
 
     if (fit.line == "exp") {  # exponential model
@@ -65,12 +77,13 @@ function(x.lv, y.lv, fit.line, fit_power) {
       b00 <- l.ln$coefficients[1]
       b11 <- l.ln$coefficients[2]
       f.ln <- exp(b00 + (b11*x.lv))
-      Rsqq <- summary(l.ln)$r.squared
       ok <- is.finite(f.ln)
       if (length(ok) > 0) {
         f.ln <- f.ln[ok]
         x.lv <- x.lv[ok]
       }
+      if (!is.null(fit_new)) 
+        y.new <- round(exp(b00 + (b11*fit_new)), digits_d)
     }
 
     if (fit.line == "log") {  # logarithmic model
@@ -98,25 +111,30 @@ function(x.lv, y.lv, fit.line, fit_power) {
         message("\n>>> Warning: ",
           "Some values of log() back transformation not defined.\n\n")
       }
-      Rsqq <- summary(l.ln)$r.squared
+      if (!is.null(fit_new)) 
+        y.new <- round(log(b00 + (b11*fit_new)), digits_d)
     }
+    # ---------------------------------------
+
+    Rsqq <- summary(l.ln)$r.squared
+
+    # linear MSE
+    e.ln <- l.ln$residuals
+    sse <- sum(e.ln^2)
+    mse.ln <- sse / (length(e.ln) - 2)  # 1 pred var
+
+    # nonlinear MSE
+    e.nl <- y.lv - f.ln
+    sse <- sum(e.nl^2)
+    mse.nl <- sse / (length(e.nl) - 2)  # 1 pred var
 
-    if (fit.line != "loess") {
-      a <- anova(l.ln)
-      mse <- a[row.names(a) == "Residuals", ][3]
-    }
-    else {  # anova() only applies to lm
-      e.lv <- l.ln$residuals
-      sse <- sum(e.lv^2)
-      mse <- sse / (length(e.lv) - 2)  # only 1 pred var
-    }
     b0 <- ifelse (is.null(b00), NA, b00) 
     b1 <- ifelse (is.null(b11), NA, b11) 
     Rsq <- ifelse (is.null(Rsqq), NA, Rsqq) 
   }  # end any(ok)
 
   return(list(x.lv=x.lv, y.lv=y.lv, f.ln=f.ln, l.ln=l.ln,
-              mse=mse, b0=b0, b1=b1, Rsq=Rsq))
-
+              mse.ln=mse.ln, mse.nl=mse.nl, b0=b0, b1=b1, Rsq=Rsq,
+              y.new=y.new))
 }
 
